pyprofit
########

.. image:: https://travis-ci.org/rtobar/pyprofit.svg?branch=master
    :target: https://travis-ci.org/rtobar/pyprofit

.. image:: https://img.shields.io/pypi/v/pyprofit.svg
    :target: https://pypi.python.org/pypi/pyprofit

.. image:: https://img.shields.io/pypi/pyversions/pyprofit.svg
    :target: https://pypi.python.org/pypi/pyprofit

.. image:: https://img.shields.io/pypi/dm/pyprofit.svg
    :target: https://pypi.python.org/pypi/pyprofit

*pyprofit* is a python wrapper for `libprofit <https://www.github.com/rtobar/libprofit>`_.
